FourdgsCameraTrajectory class

A default viewpoint and an optional suggested path. Advisory in the format and advisory here: nothing in decoding depends on it.

Constructors

FourdgsCameraTrajectory({required double fovYDeg, required List<double> position, required List<double> target, List<double> times = const <double>[], List<List<double>> positions = const <List<double>>[], List<List<double>> targets = const <List<double>>[], String interpolation = 'spline', bool loop = true})
const

Properties

fovYDeg double
final
hashCode int
The hash code for this object.
no setterinherited
interpolation String
final
loop bool
final
position List<double>
final
positions List<List<double>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target List<double>
final
targets List<List<double>>
final
times List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited