FourdgsFooter class

Constructors

FourdgsFooter({required int summaryStart, required int summaryOffsetStart, required int summaryCrc})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaryCrc int
CRC-32 (IEEE) over [summaryStart, footerStart), or 0.
final
summaryOffsetStart int
final
summaryStart int
Byte offset of the first Chunk Index record, or 0 when the file has no index and MUST be read sequentially.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List content) FourdgsFooter