FourdgsRigTrajectoryView class

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
interpolation int
no setteroverride
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
no setteroverride
trajectory FourdgsRigTrajectory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotationAt(int i) List<double>
override
timeAt(int i) double
override
toString() String
A string representation of this object.
inherited
translationAt(int i) List<double>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited