FourdgsStatistics class

Opcode 0x0C. Advisory: a reader that needs certainty computes from the chunks instead.

Constructors

FourdgsStatistics({required int gaussianCount, required int chunkCount, required double durationSec, required List<double> aabb})
const

Properties

aabb List<double>
final
chunkCount int
final
durationSec double
final
gaussianCount int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List content) FourdgsStatistics