FourdgsStreamHeader class

An attribute stream's header, read without touching its payload.

Constructors

FourdgsStreamHeader({required int attributeId, required int width, required int mode, required int codec, required int channels, required int count, required int payloadLength})
const

Properties

attributeId int
final
channels int
final
codec int
final
count int
final
hashCode int
The hash code for this object.
no setterinherited
mode int
final
payloadLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited