KeyframeDeltaSequence class

A whole keyframe-delta file, decoded by either read path.

Constructors

KeyframeDeltaSequence({required FourdgsHeader header, required FourdgsQuantization quantization, required List<FourdgsWindow> windows, required List<KeyframeDeltaChunk> chunks})

Properties

chunks List<KeyframeDeltaChunk>
final
hashCode int
The hash code for this object.
no setterinherited
final
quantization FourdgsQuantization
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windows List<FourdgsWindow>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited