t0 property
The instant this population is stated at. The sample covers [t0, t0) of
the next sample, and the last one runs to the scene duration (spec 11.1).
Implementation
final double t0;
The instant this population is stated at. The sample covers [t0, t0) of
the next sample, and the last one runs to the scene duration (spec 11.1).
final double t0;