codec property
The stream codec. Only codecDeflate is available to a pure-Dart build, which is why it is the default everywhere.
Implementation
final int codec;
The stream codec. Only codecDeflate is available to a pure-Dart build, which is why it is the default everywhere.
final int codec;