FourdgsSteps class
Grid pitches, read verbatim from the Quantization record so a decoder never re-derives a float and drifts from the encoder.
Constructors
- FourdgsSteps({required double pos, required double scaleLog, required double rot, required double rgb, required double alpha, required double motion, required double time, required double sigmaLog, required int sh})
-
const
- FourdgsSteps.of(FourdgsQuantization q)
-
factory
Properties
- alpha → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- motion → double
-
final
- pos → double
-
final
- rgb → double
-
final
- rot → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleLog → double
-
final
- sh → int
-
final
- sigmaLog → double
-
final
- time → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited