lengthUnitMetres top-level constant
Metres per unit for each registry length unit, or null for one this build
does not know. An unrecognized registry value is not a malformed one.
Implementation
const Map<int, double> lengthUnitMetres = <int, double>{
1: 1.0,
2: 0.01,
3: 0.001,
4: 1000.0,
5: 0.3048,
6: 0.0254,
};